@@ -18,6 +18,8 @@ private:
     XML *xml;
     HistoryInfoWindow *hiw;
 
+
+
     QListView *lstExercises;
     QList < QList <QString> > exercises;
     QStandardItemModel *model;
@@ -26,6 +28,8 @@ private:
 
 private slots:
     void showInfo(QModelIndex index);
+    void showContextMenuForWidget(const QPoint &pos);
+    void deleteItem();
 
 };
 
