@@ -60,6 +60,7 @@ WeightDialog::WeightDialog(QWidget *parent) :
     qDebug () << "WeightDialog::WeightDialog 6";
     connect(btnSave, SIGNAL(clicked()),this,SLOT(save()));
     qDebug () << "WeightDialog::WeightDialog 7";
+    resize(480,350);
 }
 
 void WeightDialog::load(QString name, QString grp, QString currentSet)
@@ -79,8 +80,13 @@ void WeightDialog::load(QString name, QString grp, QString currentSet)
     selectorVar->setModel(modelVar);
     qDebug () << "WeightDialog::load 3";
 
+    setWindowTitle("Save weight (set:" + currentSet + ")");
+
     list = xml->getHistoryByExercise(name);
 
+    if(list.isEmpty())
+        return;
+
     for(int i = 1; i < currentSet.toInt(); i++)
     {
         list.removeFirst();
@@ -92,7 +98,7 @@ void WeightDialog::load(QString name, QString grp, QString currentSet)
     btnReps->setValueText(list.takeFirst());
 
 
-    setWindowTitle("Save weight (set:" + currentSet + ")");
+
 
     qDebug () << "WeightDialog::load 4";
 }
@@ -120,7 +126,8 @@ void WeightDialog::loadCardio(QString name, QString m, QString s)
 
 
     list = xml->getHistoryByExercise(name);
-    btnVar->setValueText(list.takeFirst());
+    if(!list.isEmpty())
+        btnVar->setValueText(list.takeFirst());
 
 }
 
